/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PrometheusQueryLoggingConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Region where this resource will be [managed](https://docs.aws.amazon.com/general/latest/gr/rande.html#regional-endpoints). Defaults to the Region set in the [provider configuration](https://registry.terraform.io/providers/hashicorp/aws/latest/docs#aws-configuration-reference).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#region PrometheusQueryLoggingConfiguration#region}
    */
    readonly region?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#workspace_id PrometheusQueryLoggingConfiguration#workspace_id}
    */
    readonly workspaceId: string;
    /**
    * destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#destination PrometheusQueryLoggingConfiguration#destination}
    */
    readonly destination?: PrometheusQueryLoggingConfigurationDestination[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#timeouts PrometheusQueryLoggingConfiguration#timeouts}
    */
    readonly timeouts?: PrometheusQueryLoggingConfigurationTimeouts;
}
export interface PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#log_group_arn PrometheusQueryLoggingConfiguration#log_group_arn}
    */
    readonly logGroupArn: string;
}
export declare function prometheusQueryLoggingConfigurationDestinationCloudwatchLogsToTerraform(struct?: PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs | cdktf.IResolvable): any;
export declare function prometheusQueryLoggingConfigurationDestinationCloudwatchLogsToHclTerraform(struct?: PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs | cdktf.IResolvable): any;
export declare class PrometheusQueryLoggingConfigurationDestinationCloudwatchLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs | cdktf.IResolvable | undefined;
    set internalValue(value: PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs | cdktf.IResolvable | undefined);
    private _logGroupArn?;
    get logGroupArn(): string;
    set logGroupArn(value: string);
    get logGroupArnInput(): string | undefined;
}
export declare class PrometheusQueryLoggingConfigurationDestinationCloudwatchLogsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PrometheusQueryLoggingConfigurationDestinationCloudwatchLogsOutputReference;
}
export interface PrometheusQueryLoggingConfigurationDestinationFilters {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#qsp_threshold PrometheusQueryLoggingConfiguration#qsp_threshold}
    */
    readonly qspThreshold: number;
}
export declare function prometheusQueryLoggingConfigurationDestinationFiltersToTerraform(struct?: PrometheusQueryLoggingConfigurationDestinationFilters | cdktf.IResolvable): any;
export declare function prometheusQueryLoggingConfigurationDestinationFiltersToHclTerraform(struct?: PrometheusQueryLoggingConfigurationDestinationFilters | cdktf.IResolvable): any;
export declare class PrometheusQueryLoggingConfigurationDestinationFiltersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PrometheusQueryLoggingConfigurationDestinationFilters | cdktf.IResolvable | undefined;
    set internalValue(value: PrometheusQueryLoggingConfigurationDestinationFilters | cdktf.IResolvable | undefined);
    private _qspThreshold?;
    get qspThreshold(): number;
    set qspThreshold(value: number);
    get qspThresholdInput(): number | undefined;
}
export declare class PrometheusQueryLoggingConfigurationDestinationFiltersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: PrometheusQueryLoggingConfigurationDestinationFilters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PrometheusQueryLoggingConfigurationDestinationFiltersOutputReference;
}
export interface PrometheusQueryLoggingConfigurationDestination {
    /**
    * cloudwatch_logs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#cloudwatch_logs PrometheusQueryLoggingConfiguration#cloudwatch_logs}
    */
    readonly cloudwatchLogs?: PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs[] | cdktf.IResolvable;
    /**
    * filters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#filters PrometheusQueryLoggingConfiguration#filters}
    */
    readonly filters?: PrometheusQueryLoggingConfigurationDestinationFilters[] | cdktf.IResolvable;
}
export declare function prometheusQueryLoggingConfigurationDestinationToTerraform(struct?: PrometheusQueryLoggingConfigurationDestination | cdktf.IResolvable): any;
export declare function prometheusQueryLoggingConfigurationDestinationToHclTerraform(struct?: PrometheusQueryLoggingConfigurationDestination | cdktf.IResolvable): any;
export declare class PrometheusQueryLoggingConfigurationDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): PrometheusQueryLoggingConfigurationDestination | cdktf.IResolvable | undefined;
    set internalValue(value: PrometheusQueryLoggingConfigurationDestination | cdktf.IResolvable | undefined);
    private _cloudwatchLogs;
    get cloudwatchLogs(): PrometheusQueryLoggingConfigurationDestinationCloudwatchLogsList;
    putCloudwatchLogs(value: PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs[] | cdktf.IResolvable): void;
    resetCloudwatchLogs(): void;
    get cloudwatchLogsInput(): cdktf.IResolvable | PrometheusQueryLoggingConfigurationDestinationCloudwatchLogs[] | undefined;
    private _filters;
    get filters(): PrometheusQueryLoggingConfigurationDestinationFiltersList;
    putFilters(value: PrometheusQueryLoggingConfigurationDestinationFilters[] | cdktf.IResolvable): void;
    resetFilters(): void;
    get filtersInput(): cdktf.IResolvable | PrometheusQueryLoggingConfigurationDestinationFilters[] | undefined;
}
export declare class PrometheusQueryLoggingConfigurationDestinationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: PrometheusQueryLoggingConfigurationDestination[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): PrometheusQueryLoggingConfigurationDestinationOutputReference;
}
export interface PrometheusQueryLoggingConfigurationTimeouts {
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#create PrometheusQueryLoggingConfiguration#create}
    */
    readonly create?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours). Setting a timeout for a Delete operation is only applicable if changes are saved into state before the destroy operation occurs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#delete PrometheusQueryLoggingConfiguration#delete}
    */
    readonly delete?: string;
    /**
    * A string that can be [parsed as a duration](https://pkg.go.dev/time#ParseDuration) consisting of numbers and unit suffixes, such as "30s" or "2h45m". Valid time units are "s" (seconds), "m" (minutes), "h" (hours).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#update PrometheusQueryLoggingConfiguration#update}
    */
    readonly update?: string;
}
export declare function prometheusQueryLoggingConfigurationTimeoutsToTerraform(struct?: PrometheusQueryLoggingConfigurationTimeouts | cdktf.IResolvable): any;
export declare function prometheusQueryLoggingConfigurationTimeoutsToHclTerraform(struct?: PrometheusQueryLoggingConfigurationTimeouts | cdktf.IResolvable): any;
export declare class PrometheusQueryLoggingConfigurationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PrometheusQueryLoggingConfigurationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: PrometheusQueryLoggingConfigurationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration aws_prometheus_query_logging_configuration}
*/
export declare class PrometheusQueryLoggingConfiguration extends cdktf.TerraformResource {
    static readonly tfResourceType = "aws_prometheus_query_logging_configuration";
    /**
    * Generates CDKTF code for importing a PrometheusQueryLoggingConfiguration resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the PrometheusQueryLoggingConfiguration to import
    * @param importFromId The id of the existing PrometheusQueryLoggingConfiguration that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the PrometheusQueryLoggingConfiguration to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/aws/6.3.0/docs/resources/prometheus_query_logging_configuration aws_prometheus_query_logging_configuration} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PrometheusQueryLoggingConfigurationConfig
    */
    constructor(scope: Construct, id: string, config: PrometheusQueryLoggingConfigurationConfig);
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _workspaceId?;
    get workspaceId(): string;
    set workspaceId(value: string);
    get workspaceIdInput(): string | undefined;
    private _destination;
    get destination(): PrometheusQueryLoggingConfigurationDestinationList;
    putDestination(value: PrometheusQueryLoggingConfigurationDestination[] | cdktf.IResolvable): void;
    resetDestination(): void;
    get destinationInput(): cdktf.IResolvable | PrometheusQueryLoggingConfigurationDestination[] | undefined;
    private _timeouts;
    get timeouts(): PrometheusQueryLoggingConfigurationTimeoutsOutputReference;
    putTimeouts(value: PrometheusQueryLoggingConfigurationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | PrometheusQueryLoggingConfigurationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
